* ingroupchina.do

* replication .do file for:
* Ingroup Bias in Official Behavior: A National Field Experiment in China
* Greg Distelhorst and Yue Hou

clear
use ingroup_replication.dta
set more off
log using replication.txt, replace text

global ECON2 "area pop grp pcgrp_k primary secondary govrev govexp imports exports fdi"
global ETHNIC  "pctmuslim pcthan"
global REPLIES "i.junegroup"

* Table 1: Ethnic Identity and Government Disclosure
ttest disc4wk, by(tr) une
* percent change
di (r(mu_1)-r(mu_2)) / r(mu_1)
ranksum disc4wk, by(tr)


* Table 2: Ingroup bias among political elites in South Africa etc. (China only)
ttest disc4wk if musmayor==0 & musmayor!=., by(tr) une
* Percent change
di (r(mu_1)-r(mu_2)) / r(mu_1)


* Table 3: Interaction Effects
global IF if pctmuslim < .1 & pctmuslim != .
reg disc4wk_100 tr $ECON2 pctmuslim pcthan $REPLIES $IF, cluster(provnum)
outreg2 using xx_interact_3.tex, dec(1) tex replace
reg disc4wk_100 tr tr_pctmuslim100 pctmuslim100 $ECON2 pcthan $REPLIES $IF, cluster(provnum)
outreg2
reg disc4wk_100 tr tr_muspop muspop $ECON2 pctmuslim pcthan $REPLIES $IF, cluster(provnum)
outreg2
reg disc4wk_100 tr tr_conflict conflict $ECON2 $ETHNIC $REPLIES, cluster(provnum)
outreg2

* Reply lengths among disclosers
ttest replylen if disc==1, by(tr) une
* We recovered the fulltext responses for 102 prefs out of 111 total disclosers.
* Fulltext responses were gathered several months after initial data collection.
* In the meantime, several localities had deleted old messages.

* Appendix Table C2: Response rates and quality of response
sum disc score_govname score_standards score_procedures score_contact score_support
sum rscore if disc==1
count if replied=="Y" & disc==1
di r(N) / 258
count if replied=="Y" & disc==0
di r(N) / 258
count if replied=="N"
di r(N) / 258


* Appendix Table C3: Govt Notes Inaccurate contact info
ttest noticed_bad_info, by(tr) une

* Appendix Table C4: Alternative time cutoffs
foreach wk in 1 2 3 4 5 6 {
    di "Week = `wk'"
	ttest disc`wk'wk, by(tr) une
}
* 30 weeks
ttest disc, by(tr) une


* Appendix Table C5: Regression estimates
reg disc4wk_100 tr, robust
outreg2 using xxreg.tex, dec(1) tex replace
reg disc4wk_100 tr $ECON2, robust
outreg2
reg disc4wk_100 tr $ECON2 $ETHNIC, robust
outreg2
reg disc4wk_100 tr $ECON2 $ETHNIC $REPLIES, robust
outreg2
reg disc4wk_100 tr $ECON2 $ETHNIC $REPLIES i.provnum, robust
outreg2

log close
